@@ -1,15 +1,12 @@
 # -*- coding: utf-8 -*-
 
 from audio import AudioHandler
-from base import LanguageHandler
-from pofile import POFileHandler
-from rstfile import reSTFileHandler
+from base import LanguageHandler, NullHandler
 from text import SingleSentenceHandler
 
 __all__ = [
     "AudioHandler",
     "LanguageHandler",
-    "POFileHandler",
-    "reSTFileHandler",
+    "NullHandler",
     "SingleSentenceHandler",
 ]
