@@ -1,7 +1,33 @@
 # -*- coding: utf-8 -*-
 
+import os
 import re
 
+try:
+    from ikazuchi.locale import _
+except ImportError:
+    def _(s): return s
+
+def get_file_from_args(args, start=0, end=1):
+    """ check file arguments and the existence
+    >>> import tempfile
+    >>> f = tempfile.NamedTemporaryFile()
+    >>> files = get_file_from_args([f.name])
+    >>> len(files)
+    1
+    >>> files = get_file_from_args([f.name, f.name], start=0, end=2)
+    >>> len(files)
+    2
+    >>> f.close()
+    """
+    files = args[start:end] if args[start:end] else None
+    if not files:
+        raise ValueError(_(u"Give file as \"-p plugin_name xxx\""))
+    for f in files:
+        if not os.access(f, os.R_OK):
+            raise  ValueError(_(u"Cannot access file: {0}").format(f))
+    return files
+
 def concatenate_lines(lines, pattern):
     """ concatenate lines
     >>> import re
