@@ -12,13 +12,9 @@ def get_lang():
     return lang
 
 def get_handler(opts):
-    h = None
+    h = NullHandler()
     if opts.lang:
         h = LanguageHandler(opts.api, opts.encoding)
-    elif opts.po_file:
-        h = POFileHandler(opts.api, opts.po_file[0], opts.encoding)
-    elif opts.rst_file:
-        h = reSTFileHandler(opts)
     elif opts.sentences:
         # FIXME: consider later about audio handler
         if (opts.sentences[0] == "audio" or opts.sentences[-1] == "audio") \
